ProSHADE: Namespace Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Here is a list of all documented namespace members with links to the namespaces they belong to:

### - m -

- MapManipulationTask() : ProSHADE_internal_tasks
- MapOverlayTask() : ProSHADE_internal_tasks
- missingAxisHeight() : ProSHADE_internal_symmetry
- moveMapByFourier() : ProSHADE_internal_mapManip
- moveMapByIndices() : ProSHADE_internal_mapManip
- movePDBForMapCalc() : ProSHADE_internal_mapManip
- multiplyGroupElementMatrices() : ProSHADE_internal_maths
- multiplyTwoSquareMatrices() : ProSHADE_internal_maths
- myRound() : ProSHADE_internal_mapManip